Thanks goes to these wonderful people (`emoji key <https://allcontributors.org/docs/en/emoji-key>`_):

.. raw:: html

    <table class="table table-bordered">
        <tr>
            <td align="center">
                <a href="https://www.linkedin.com/in/pierrickrambaud/">
                    <img src="https://avatars3.githubusercontent.com/u/12596392?v=4" width="70px;" alt="12rambau"/><br />
                    <sub><b>Pierrick Rambaud</b></sub>
                </a>
                <br/>
                <a href="#code" title="Code">💻</a> 
                <a href="#ideas" title="Ideas, Planning, & Feedback">🤔</a> 
                <a href="#question" title="Answering Questions">💬</a> 
                <a href="#issue" title="Bug reports">🐛</a> 
                <a href="#documentation" title="Documentation">📖</a> 
                <br/>
                <a href="#maintenance" title="Maintenance">🚧</a> 
                <a href="#review" title="Reviewed Pull Requests">👀</a> 
                <a href="#test" title="Tests">⚠️</a>
                <a href="#example" title="Examples">💡</a>
                <a href="#infra" title="Infrastructure">🚇</a>
            </td>
        </tr>
    </table>

This project follows the `all-contributors <https://allcontributors.org>`_ specification.

Contributions of any kind are welcome!